# speedtest

Dual-method internet speed test: speedtest-cli (Ookla) + iperf3. Measures download, upload, latency, and jitter.

## Structure

- `schema.json`: Interface
- `tool.py`: CLI
- worker.py: Background
